==> snow-0.2.0.tar.gz: snow-0.2.0/README.md <==
Snow: Python library for ServiceNow
---

[![image](https://img.shields.io/github/license/rbw/snow?style=flat-square)](https://raw.githubusercontent.com/rbw/snow/master/LICENSE)
[![image](https://img.shields.io/pypi/v/snow?style=flat-square)](https://pypi.org/project/snow)
[![image](https://img.shields.io/travis/rbw/snow?style=flat-square)](https://travis-ci.org/rbw/snow)
[![image](https://img.shields.io/pypi/pyversions/snow?style=flat-square)](https://pypi.org/project/snow)
[![image](https://pepy.tech/badge/snow/month)](https://pepy.tech/project/snow)


Snow is a simple and lightweight yet powerful and extensible library for interacting with ServiceNow. It works
with modern versions of Python and utilizes [asyncio](https://docs.python.org/3/library/asyncio.html).

Documentation
---

The Snow API reference, examples and more is available in the [documentation](https://python-snow.readthedocs.io/en/latest).

Development status
---

Pre-alpha

Funding
-------

The Snow code is permissively licensed, and can be incorporated into any type of application–commercial or otherwise–without costs or limitations.
Its author believes it's in the commercial best-interest for users of the project to invest in its ongoing development.

Consider leaving a [donation](https://paypal.vault13.org) if you like this software, it will:

- Directly contribute to faster releases, more features, and higher quality software.
- Allow more time to be invested in documentation, issue triage, and community support.
- Safeguard the future development of Snow.

Author
------

Robert Wikman \<rbw@vault13.org\>

==> snow-0.2.1.tar.gz: snow-0.2.1/README.md <==
<p align="center">
  <img width="256" height="256" src="extras/images/logo-gh.png">
  <br><br>
  <b>Python library for ServiceNow</b><br>
</p>

[![image](https://badgen.net/pypi/v/snow)](https://pypi.org/project/snow)
[![image](https://badgen.net/badge/python/3.7+?color=purple)](https://pypi.org/project/snow)
[![image](https://badgen.net/travis/rbw/snow)](https://travis-ci.org/rbw/snow)
[![image](https://badgen.net/pypi/license/snow)](https://raw.githubusercontent.com/rbw/snow/master/LICENSE)
[![image](https://pepy.tech/badge/snow/month)](https://pepy.tech/project/snow)


Snow is a simple and lightweight yet powerful and extensible library for interacting with ServiceNow. It works
with modern versions of Python and utilizes [asyncio](https://docs.python.org/3/library/asyncio.html).

Documentation
---

The Snow API reference, examples and more is available in the [documentation](https://python-snow.readthedocs.io/en/latest).

Development status
---

Pre-alpha

Funding
-------

The Snow code is permissively licensed, and can be incorporated into any type of application–commercial or otherwise–without costs or limitations.
Its author believes it's in the commercial best-interest for users of the project to invest in its ongoing development.

Consider leaving a [donation](https://paypal.vault13.org) if you like this software, it will:

- Directly contribute to faster releases, more features, and higher quality software.
- Allow more time to be invested in documentation, issue triage, and community support.
- Safeguard the future development of Snow.

Author
------

Robert Wikman \<rbw@vault13.org\>
